==> thx_tour-0.1.4.tar.gz: thx_tour-0.1.4/thx/tour/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# BOX
class BoxSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box'
        model = models.Box
        fields = '__all__'


class BoxListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_list'
        model = models.Box
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class BoxRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_retrieve'
        model = models.Box
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class BoxCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_create'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class BoxUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_update'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class BoxPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_partial_update'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class BoxEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_enable'
        model = models.Box
        fields = ()
        response_serializer = BoxRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class BoxDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_disable'
        model = models.Box
        fields = ()
        response_serializer = BoxRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class BoxLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_light'
        model = models.Box
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# TOUR
class TourSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour'
        model = models.Tour
        fields = '__all__'


class TourListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    boxes = BoxListSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_tour_tour_list'
        model = models.Tour
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class TourRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    boxes = BoxListSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_tour_tour_retrieve'
        model = models.Tour
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class TourGetByCodeSerializer(TourRetrieveSerializer):
    class Meta(TourRetrieveSerializer.Meta):
        ref_name = 'v1_tour_tour_get_by_code'


class TourCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_create'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class TourUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_update'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class TourPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_partial_update'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class TourEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_enable'
        model = models.Tour
        fields = ()
        response_serializer = TourRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class TourDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_disable'
        model = models.Tour
        fields = ()
        response_serializer = TourRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class TourLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_light'
        model = models.Tour
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

==> thx_tour-0.1.6.tar.gz: thx_tour-0.1.6/thx/tour/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# BOX
class BoxSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box'
        model = models.Box
        fields = '__all__'


class BoxListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_list'
        model = models.Box
        fields = '__all__'


class BoxRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_retrieve'
        model = models.Box
        fields = '__all__'


class BoxCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_create'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer


class BoxUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_update'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer


class BoxPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_partial_update'
        model = models.Box
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = BoxRetrieveSerializer


class BoxEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_enable'
        model = models.Box
        fields = ()
        response_serializer = BoxRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class BoxDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_disable'
        model = models.Box
        fields = ()
        response_serializer = BoxRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class BoxLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_box_light'
        model = models.Box
        fields = ('id', 'status', 'status_display',)


# TOUR
class TourSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour'
        model = models.Tour
        fields = '__all__'


class TourListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    boxes = BoxListSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_tour_tour_list'
        model = models.Tour
        fields = '__all__'


class TourRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    boxes = BoxListSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_tour_tour_retrieve'
        model = models.Tour
        fields = '__all__'


class TourGetByCodeSerializer(TourRetrieveSerializer):
    class Meta(TourRetrieveSerializer.Meta):
        ref_name = 'v1_tour_tour_get_by_code'


class TourCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_create'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer


class TourUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_update'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer


class TourPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_partial_update'
        model = models.Tour
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = TourRetrieveSerializer


class TourEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_enable'
        model = models.Tour
        fields = ()
        response_serializer = TourRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class TourDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_disable'
        model = models.Tour
        fields = ()
        response_serializer = TourRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class TourLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_tour_tour_light'
        model = models.Tour
        fields = ('id', 'status', 'status_display',)
